﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class BoatController : MonoBehaviour
{
    [SerializeField]
    private float speed = 100;

    private Rigidbody rigidbody;
    private Vector3 velocity3D;
    private Vector3 initialPosition;

    // Use this for initialization
    void Awake() {
        rigidbody = GetComponentInChildren<Rigidbody>();
        initialPosition = this.transform.position;

    }

    public void OnEnable()
    {
        Main.Register(this);
    }

    public void OnDestroy()
    {
        Main.UnRegister(this);
    }

    public void Reset()
    {
        rigidbody.velocity = Vector3.zero;
        this.transform.position = initialPosition;
    }

    // Update is called once per frame
    void Update() {

        if (Main.Instance.WaveManager.IsEnded)
        {
            this.transform.position = new Vector3(this.transform.position.x, this.transform.position.y - Time.deltaTime * 100, this.transform.position.z);
            return;
        }

        var pos = new Vector2(this.transform.localPosition.x, this.transform.localPosition.z);
        float height;
        var velocity = Main.Instance.WaveManager.GetForceAt(pos, out height);
        Vector2 newVelocity = velocity * Time.deltaTime * speed;
        velocity3D = new Vector3(newVelocity.x, 0, newVelocity.y);

        transform.position = new Vector3(transform.position.x, height*3, transform.position.z);
        if (rigidbody != null)
        {
            rigidbody.AddForce(velocity3D);
        }
    }

    public void OnDrawGizmos()
    {
        var pos = transform.position + Vector3.up * 10;

        var hasForce = velocity3D.sqrMagnitude > 0;

        Gizmos.color = hasForce ? Color.yellow : Color.red;
        Gizmos.DrawSphere(pos, 1f);

        if (!hasForce)
            return;

        Gizmos.DrawRay(pos, velocity3D.normalized * 5);
    }
}