﻿using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;

[RequireComponent(typeof(Rigidbody))]
public class FoamHead : MonoBehaviour {


    [SerializeField] float maxPressure = 20;
    [SerializeField] float pressureDecrease = 0.2f;
    [SerializeField] float pressureIncrease = 0.1f;
    float pressure = 20f;

    [HideInInspector]public bool canUseFoam = true;

    private bool makingWaves = false;


    Rigidbody rigidBody;
    public float speed = 25f;

    [SerializeField]GameObject pressurePointer;
    float pressureMaxRot = 225f;
    float pressureMinRot = 135f;
    float finalRot;
    private Coroutine waveEmitter;
    private AudioSource sound;

    ParticleSystem steam;
    private int waveID;

    public bool MakingWaves
    {
        get
        {
            return makingWaves;
        }

        set
        {
            if (makingWaves == value)
                return;

            makingWaves = value;

            if (makingWaves)
                waveEmitter = StartCoroutine(WaveEmitter());
        }
    }

    public void Awake()
    {
        sound = GetComponent<AudioSource>();
        steam = transform.GetComponentInChildren<ParticleSystem>();
    }

    private void Start()
    {
        pressure = maxPressure;
        rigidBody = GetComponent<Rigidbody>();
    }

    void Update()
    {
        if (GameStateManager.instance.GetState() == GameStates.PLAYING)
        {
            if (pressure < maxPressure && !MakingWaves)
            {
                pressure += pressureIncrease;
            }

            if (!canUseFoam && pressure >= (maxPressure/2))
            {
                canUseFoam = true;
            }
            if(pressure >= 10f)
            {
                float pressureStep = pressure - 10;
                finalRot = 360 - (pressureStep * 12);
            }else
            {
                float pressureStep = 10 - pressure;
                finalRot = pressureStep * 12;
            }
            pressurePointer.transform.localEulerAngles = new Vector3(pressurePointer.transform.localEulerAngles.x, pressurePointer.transform.localEulerAngles.y, finalRot);
        }
    }

    public void PutFHInCoffeMakeWaves()
    {
        if (pressure > 0f && canUseFoam)
        {
            pressure -= pressureDecrease;
            MakingWaves = true;
           
        }
        else
        {
            MakingWaves = false;
            canUseFoam = false;
        }
    }

    private IEnumerator WaveEmitter()
    {
        var wait = new WaitForSeconds(0.5f);
        var waitShort = new WaitForSeconds(0.05f);
        var duration = 0.1f;
        DateTime startTime;

        sound.volume = 0f;
        sound.Play();

        // Fade in / warm up
        steam.Play();
        startTime = DateTime.Now;
        while ((DateTime.Now - startTime).TotalSeconds < duration)
        {
            float progress = (float)(DateTime.Now - startTime).TotalSeconds / duration;
            sound.volume = Mathf.Clamp01(progress);
            yield return waitShort;
        }

        sound.volume = 1f;

        while (makingWaves)
        {
            waveID = Main.Instance.WaveManager.Add(new Vector2(this.transform.localPosition.x, this.transform.localPosition.z), 3);
            yield return wait;
        }


        // Fade out
        steam.Stop();
        startTime = DateTime.Now;
        while ((DateTime.Now - startTime).TotalSeconds <duration)
        {
            float progress = (float)(DateTime.Now - startTime).TotalSeconds / (duration);
            sound.volume = Mathf.Clamp01(1-progress);
            yield return waitShort;
        }
        
        sound.Stop();
        sound.volume = 0f;
    }

    public void Move(float _x, float _z)
    {
        rigidBody.velocity = new Vector3(_x * speed * Time.deltaTime, 0, _z * speed * Time.deltaTime);
    }
}
