﻿using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;

[RequireComponent(typeof(WaveManager))]
public class Main : MonoBehaviour
{
    [SerializeField]
    private bool SpawnMallows = true;

    [SerializeField]
    private float decrease = 0.9999f;

    [SerializeField]
    private float cap = 1f;

    [SerializeField]
    private float spawnDelay = 3;

    private static Main _instance;

    public static Main Instance { get { return _instance; } }

    internal static void Register(BoatController boatController)
    {
        boats.Add(boatController);
    }

    internal static void UnRegister(BoatController boatController)
    {
        boats.Remove(boatController);
    }

    public static void Reset()
    {
        foreach (var item in boats)
        {
            item.Reset();
        }
    }

    public WaveManager WaveManager { get; private set; }

    [SerializeField]
    private GameObject MarshmallowTemplate;

    private float deltaTime;
    private static List<BoatController> boats = new List<BoatController>();

    public void Awake()
    {
        _instance = this;
        SceneManager.LoadScene("Environment", LoadSceneMode.Additive);
    }

    public void Start()
    {
        WaveManager = GetComponent<WaveManager>();
    }

    public void Update()
    {
        deltaTime += Time.deltaTime;

        if (!SpawnMallows)
            return;

        if (WaveManager.IsEnded)
            return;

        if (deltaTime > spawnDelay)
        {
            deltaTime -= spawnDelay;

            var randomVec = UnityEngine.Random.insideUnitSphere;
            var h = WaveManager.DesiredWidth/2;
            var instance = Instantiate(MarshmallowTemplate,
                WaveManager.transform.position +
                new Vector3(randomVec.x * h, h * 4, randomVec.z * h), Quaternion.identity);

            spawnDelay = Mathf.Min(cap, spawnDelay * decrease);
        }
    }
}
