﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class GameManager : MonoBehaviour {

    public static GameManager instance;


    [SerializeField]GameObject pause;
    [SerializeField]Text marshmallowCounterText;
    [SerializeField]Text cookieCounterText;

    int cookieCounter = 0;
    int marshmallowCounter = 0;

    private void Awake()
    {
        if (instance == null) instance = this;
        if (instance != this) Destroy(gameObject);
        //DontDestroyOnLoad(this);
    }

    void Start()
    {
        GameStateManager.instance.playing += Playing;
        GameStateManager.instance.win += WinGame;
        GameStateManager.instance.paused += PauseGame;

        pause.SetActive(false);
        Time.timeScale = 1f;

        marshmallowCounterText.text = 0.ToString();
        cookieCounterText.text = 0.ToString();
    }

    Player winningPlayer = Player.NONE;

    public void WinCounter(Player _player)
    {
        switch (_player)
        {
            case Player.NONE:
                break;
            case Player.MARSHMALLOW:
                marshmallowCounter++;
                marshmallowCounterText.text = marshmallowCounter.ToString();
                if (marshmallowCounter >= 3)
                {
                    winningPlayer = Player.MARSHMALLOW;
                    GameStateManager.instance.SetState(GameStates.WIN);
                }
                break;
            case Player.COOKIE:
                cookieCounter++;
                cookieCounterText.text = cookieCounter.ToString();
                if (cookieCounter >= 3)
                {
                    winningPlayer = Player.COOKIE;
                    GameStateManager.instance.SetState(GameStates.WIN);
                }
                break;
            default:
                break;
        }
    }

    void WinGame()
    {
        Time.timeScale = 0f;
        switch (winningPlayer)
        {
            case Player.NONE:
                break;
            case Player.MARSHMALLOW:
                Application.LoadLevel("Win Marshmallow");
                break;
            case Player.COOKIE:
                Application.LoadLevel("Win Keks");
                break;
            default:
                break;
        }

    }

    void PauseGame()
    {
        Time.timeScale = 0f;
        pause.SetActive(true);
    }

    void Playing()
    {
        Time.timeScale = 1f;
        pause.SetActive(false);
    }
}
